# Generated by Django 2.0 on 2017-12-27 21:22

import binascii
import os
import secrets
import string

from django.conf import settings
from django.contrib.auth.hashers import make_password
from django.utils.crypto import get_random_string
from django.db import migrations, models


def create_dj_user(apps, schema_editor):
    User = apps.get_model('core', 'RadioUser')
    Token = apps.get_model('authtoken', 'Token')
    db_alias = schema_editor.connection.alias

    chars = string.ascii_letters + string.digits + string.punctuation
    new_password = get_random_string(length=32, allowed_chars=chars)
    dj = User(email=settings.RADIO_DJ_EMAIL,
              name=settings.RADIO_DJ_NAME,
              password=make_password(new_password),
              is_superuser=False,
              is_staff=True,
              is_dj=True)
    dj.save(using=db_alias)

    # Since 'post_save' is impervious to migration scripts, this will be
    # created here instead. Otherwise, key will be blank and we don't want
    # that for the DJ account.
    token = Token(key=secrets.token_hex(20), user=dj)
    token.save(using=db_alias)

    with open(os.path.join(settings.PROJECT_DIR, '.djinfo'), 'w') as f:
        f.write('Email: {}\n'.format(dj.email))
        f.write('Name: {}\n'.format(dj.name))
        f.write('Password: {}\n'.format(new_password))
        f.write('Token: {}\n'.format(token.key))


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(create_dj_user),
    ]
